Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(945)

Unified Diff: third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h

Issue 2552343009: [Presentation API] Adds DOMString[] constructor to PresentationRequest. (Closed)
Patch Set: resolve code review comments from mlamouri Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
diff --git a/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h b/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
index 860e9e4b0a181044d776a0e23e3f082e2d9f5c0b..2fb801f627bb1a50689f4acae3ca4eaf800b3ed0 100644
--- a/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
+++ b/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
@@ -9,6 +9,7 @@
#include "platform/weborigin/KURL.h"
#include "public/platform/WebCallbacks.h"
#include "wtf/Noncopyable.h"
+#include "wtf/Vector.h"
namespace blink {
@@ -17,11 +18,13 @@ struct WebPresentationError;
// PresentationAvailabilityCallback extends WebCallbacks to resolve the
// underlying promise depending on the result passed to the callback. It takes a
// KURL in its constructor and will pass it to the WebAvailabilityObserver.
class PresentationAvailabilityCallbacks final
: public WebCallbacks<bool, const WebPresentationError&> {
public:
- PresentationAvailabilityCallbacks(ScriptPromiseResolver*, const KURL&);
+ PresentationAvailabilityCallbacks(ScriptPromiseResolver*,
+ const WTF::Vector<KURL>&);
~PresentationAvailabilityCallbacks() override;
void onSuccess(bool value) override;
@@ -29,7 +32,7 @@ class PresentationAvailabilityCallbacks final
private:
Persistent<ScriptPromiseResolver> m_resolver;
- const KURL m_url;
+ const WTF::Vector<KURL> m_urls;
WTF_MAKE_NONCOPYABLE(PresentationAvailabilityCallbacks);
};
@@ -17,11 +18,13 @@ struct WebPresentationError;
// PresentationAvailabilityCallback extends WebCallbacks to resolve the
// underlying promise depending on the result passed to the callback. It takes a
-// KURL in its constructor and will pass it to the WebAvailabilityObserver.
+// WTF::Vector<KURL> in its constructor and will pass it to the
+// WebAvailabilityObserver.
class PresentationAvailabilityCallbacks final
: public WebCallbacks<bool, const WebPresentationError&> {

Powered by Google App Engine
This is Rietveld 408576698